<?php

namespace Drupal\mailjet_sign_up\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Mailjet\Client;
use Mailjet\Resources;


class SignUpForm extends FormBase {

  /**
   * @inheritdoc
   */
  public function getFormId() {
    return 'mailjet_sign_up_form';
  }

  /**
   * @inheritdoc
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $form_state->getBuildInfo()['args'][0];

    $form['header'] = ['#markup' => '<span class="intro">' . $config['header'] . '</span>'];
    $form['mail'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => $config['placeholder']],
      '#default_value' => '',
      '#required' => TRUE,
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('OK'),
    ];
    return $form;
  }

  /**
   * @inheritdoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $form_state->getBuildInfo()['args'][0];
    $mailjet = new Client($config['api_key'], $config['secret_key']);
    $email = $form_state->getValue('mail');

    // Get the list ID.
    $response = $mailjet->get(Resources::$Contactslist);

    if ($response->success()) {

      // We assume there's only one list.
      $list_id = $response->getData()[0]['ID'];

      $response = $mailjet->post(Resources::$ContactslistManagecontact, [
        'id' => $list_id,
        'body' => ['Email' => $email, 'Action' => 'addforce'],
      ]);

      if ($response->success()) {
        drupal_set_message($this->t('You successfully signed up to our newsletter. Thank you!'));
        return;
      }
    }

    drupal_set_message($this->t('Sorry, your sign-up failed.'), 'error');
    if ($response->getReasonPhrase()) {
      drupal_set_message($this->t("Here's the error message from Mailjet subscription manager: %error", ['%error' => $response->getReasonPhrase()]), 'error');
    }
  }

}
